==========================
Sample configuration files
==========================

Configuration files can alter how Mistral behaves at runtime and by default
are located in ``/etc/mistral/``. Links to sample configuration files can be
found below:

.. toctree::

   policy-yaml.rst
